pub enum DType {
Show 23 variants
I8,
I16,
F32,
F64,
U8,
U16,
I32,
I64,
U32,
U64,
Bool,
Bitset,
F16,
BF16,
F8,
I4,
I2,
I1,
U4,
U2,
U1,
T2,
T1,
}Expand description
Supported element dtypes.
Variants
Implementations
Sourceimpl DType
impl DType
Sourcepub fn from_ident(ident: &str) -> Result<Self>
pub fn from_ident(ident: &str) -> Result<Self>
Parse a dtype from its identifier string.
Sourcepub fn is_universal(self) -> bool
pub fn is_universal(self) -> bool
True if the dtype is supported across all backends.
Sourcepub fn is_signed_int(self) -> bool
pub fn is_signed_int(self) -> bool
True if the dtype is a signed integer type.
Sourcepub fn is_packed_signed(self) -> bool
pub fn is_packed_signed(self) -> bool
True if the dtype is a packed signed integer type.
Sourcepub fn storage_len(self, logical_len: usize) -> usize
pub fn storage_len(self, logical_len: usize) -> usize
Storage length in elements for a logical length.