Graph

Struct Graph 

pub struct Graph {
    pub vars: HashMap<String, VarDecl>,
    pub blocks: HashMap<String, Block>,
    /* private fields */
}
Graph structure containing blocks and variable declarations.

Fields

vars: HashMap<String, VarDecl>blocks: HashMap<String, Block>

Implementations

Source

impl Graph

pub fn new() -> Self

Create an empty graph with no blocks or variables.

Example
let mut g = Graph::new();
g.add_block("entry");
g.add_var(MemoryKind::Dynamic, "x", DType::F32, vec!["B".into()], None, None, vec![], None, false, vec![], vec![]);
g.add_node("entry", NodeKind::Return)?;
pub fn add_var( &mut self, kind: MemoryKind, name: impl Into<String>, dtype: DType, dims: Vec<String>, init: Option<ScalarValue>, ref_name: Option<String>, table_indices: Vec<String>, pattern: Option<String>, table: bool, auto_dim: Vec<String>, fixed: Vec<(String, usize)>, )

Add a variable declaration to the graph.

pub fn add_block(&mut self, name: impl Into<String>)

Ensure a block exists, creating it if missing.

pub fn add_node(&mut self, block: &str, kind: NodeKind) -> Result<()>

Append a node to a block by name.

pub fn add_prebuilt_node(&mut self, block: &str, node: Node) -> Result<()>

Append a prebuilt node to a block by name.

pub fn make_node(&mut self, kind: NodeKind) -> Node

Allocate a node with a fresh index and UUID.

pub fn make_loop_node( &mut self, name: impl Into<String>, index: impl Into<String>, start: impl Into<String>, end: impl Into<String>, body: Vec<Node>, ) -> Node

Allocate a loop node with a fresh index and UUID.

pub fn block(&self, name: &str) -> Result<&Block>

Fetch a block by name.