pub struct Random<T> { /* private fields */ }Expand description
Random tensor generator for a specific element type.
Implementations
Sourceimpl<T> Random<T>where
T: RandomValue,
impl<T> Random<T>where
T: RandomValue,
Sourcepub fn generate(range: (T, T), len: usize) -> Result<Tensor<T>>
pub fn generate(range: (T, T), len: usize) -> Result<Tensor<T>>
Generate a tensor with a default seed and options.
Sourcepub fn generate_with_opts(
range: (T, T),
len: usize,
opts: TensorOptions,
) -> Result<Tensor<T>>
pub fn generate_with_opts( range: (T, T), len: usize, opts: TensorOptions, ) -> Result<Tensor<T>>
Generate a tensor with custom options and default seed.
Sourcepub fn generate_with_seed(
seed: u64,
range: (T, T),
len: usize,
) -> Result<Tensor<T>>
pub fn generate_with_seed( seed: u64, range: (T, T), len: usize, ) -> Result<Tensor<T>>
Generate a tensor with an explicit seed.
Sourcepub fn generate_with_seed_opts(
seed: u64,
range: (T, T),
len: usize,
opts: TensorOptions,
) -> Result<Tensor<T>>
pub fn generate_with_seed_opts( seed: u64, range: (T, T), len: usize, opts: TensorOptions, ) -> Result<Tensor<T>>
Generate a tensor with an explicit seed and options.
Sourcepub fn next(&mut self, range: (T, T), len: usize) -> Result<Tensor<T>>
pub fn next(&mut self, range: (T, T), len: usize) -> Result<Tensor<T>>
Generate the next tensor using the internal RNG.
Sourcepub fn next_with_opts(
&mut self,
range: (T, T),
len: usize,
opts: TensorOptions,
) -> Result<Tensor<T>>
pub fn next_with_opts( &mut self, range: (T, T), len: usize, opts: TensorOptions, ) -> Result<Tensor<T>>
Generate the next tensor using the internal RNG and options.